-------------------------------------------------------------------------------
--|> SPLASH SCREEN
--: Creates a splash screen window for a static display of info
-------------------------------------------------------------------------------
--|> UPVALUE GLOBALS
-------------------------------------------------------------------------------
local weizPVP = weizPVP
local CreateFrame = CreateFrame
local UIFrameFadeOut = UIFrameFadeOut
local UIFrameFadeIn = UIFrameFadeIn
local C_Timer = C_Timer
local math = math

-------------------------------------------------------------------------------
--|> LIBS
-------------------------------------------------------------------------------
local SM = LibStub:GetLibrary("LibSharedMedia-3.0")

-------------------------------------------------------------------------------
--|> GLOBAL FUNCTIONS
-------------------------------------------------------------------------------
--> Splash Frame Generate
-------------------------------------------------------------------------------

local recentChanges = {
    [1] = {
        ["Stealth Alerts and Detection"] = {
            "Visual Updates",
            "Alerts are now shown on the status bar as well"
        }
    },
    [2] = {
        ["Crosshairs"] = {
            "Recreated higher resolution image assets for sharper scaling.",
            "Additional options added",
            "Name and Guild text added back as options",
            ["Toggle Crosshairs On/Off using this command"] = {"|cff42dcf4»  |r|cffffa012/wpvp ch|r"}
        }
    }
}
--> use icons
-- local text = "|T".. iconNumer ..":15:15:0:0:64:64:4:60:4:60|t "
-- |TInterface\\...:16:16:0:0:64:64:4:60:4:60|t Coins

local SplashDetailsText = "|cff37ff37 Stealth Alerts and Detection|r\n"
SplashDetailsText = SplashDetailsText .. "    • Visual Updates\n"
SplashDetailsText = SplashDetailsText .. "    • Alerts are now shown on the status bar as well\n"
SplashDetailsText = SplashDetailsText .. "\n|cff37ff37 Crosshairs|r\n"
SplashDetailsText = SplashDetailsText .. "    • Recreated higher resolution image assets for sharper scaling.\n"
SplashDetailsText = SplashDetailsText .. "    • More options added\n"
SplashDetailsText = SplashDetailsText .. "    • Name and Guild text added back as Crosshair options\n"
SplashDetailsText = SplashDetailsText .. "    • Toggle Crosshairs On/Off using this command\n"
SplashDetailsText = SplashDetailsText .. "        |cff42dcf4»|r  |cffffa012/wpvp ch|r\n"
SplashDetailsText = SplashDetailsText .. "    • Toggle Crosshairs keybind added\n"
SplashDetailsText = SplashDetailsText .. "\n|cff37ff37 Interface and Media|r\n"
SplashDetailsText = SplashDetailsText .. "    • Multiple UI adjustments (colors/animations/fonts/etc)\n"
SplashDetailsText = SplashDetailsText .. "    • 'MLG Air Horn' sound effect added to sound library\n"
SplashDetailsText = SplashDetailsText .. "\n|cff37ff37 Fixes|r\n"
SplashDetailsText = SplashDetailsText .. "    • Resolved some bugs related to the window display.\n"
SplashDetailsText = SplashDetailsText .. "    • Many smaller issues fixed or code improved to prevent some.\n"
SplashDetailsText = SplashDetailsText .. "\n |cff37ff37Issues after updating?|r Try restting the options: \n"
SplashDetailsText = SplashDetailsText .. "    |cff42dcf4»|r  |cffffa012/wpvp resetOptions|r\n"
SplashDetailsText = SplashDetailsText .. "\n"

function weizPVP:CreateSplashScreen()
    --> CREATE SPLASH WINDOW
    local f = CreateFrame("Frame", "weizPVPSplashScreen", UIParent)
    f:SetFrameStrata("DIALOG")
    f:SetFrameLevel(140)
    f:SetPoint("TOP", 0, UIParent:GetTop() - 300)
    f:SetWidth(532)
    f:SetBackdrop(
        {
            bgFile = SM:Fetch("background", "weizPVP: #FFFFFF"),
            tile = false,
            edgeFile = SM:Fetch("border", "weizPVP: Border"),
            edgeSize = 1,
            insets = {left = 1, right = 1, top = 1, bottom = 1}
        }
    )
    f:SetBackdropColor(0.1, 0.1, 0.1, 0)
    f:SetBackdropBorderColor(0, 0, 0, 1)
    f:SetClampedToScreen(true)
    f:SetMovable(true)
    f:EnableMouse(true)
    f:RegisterForDrag("LeftButton")
    f:SetDontSavePosition(true)
    f:SetScript(
        "OnDragStart",
        function()
            f:StartMoving()
        end
    )
    f:SetScript(
        "OnDragStop",
        function()
            f:StopMovingOrSizing()
        end
    )
    f:Hide()

    --=> CinModelBG
    -----------------------------------------------------------
    f.pepe = CreateFrame("CinematicModel", "splash pepe", f)
    f.pepe:SetFrameStrata("DIALOG")
    f.pepe:SetSize(100, 100)
    f.pepe:SetFrameLevel(160)
    f.pepe:SetModelDrawLayer("ARTWORK", 1)
    f.pepe:SetParent(f)
    f.pepe:SetPoint("BOTTOMRIGHT", f, "TOPRIGHT", 0, -28)
    f.pepe:SetModel([[world/expansion05/doodads/orc/doodads/6hu_garrison_orangebird_var2]])
    f.pepe:RefreshUnit()
    f.pepe:ClearTransform()
    f.pepe:SetModelScale(2)
    f.pepe:SetPitch(-0.25)

    --!! SetLight(enabled[, omni, dirX,dirY,dirZ, ambIntensity[,ambR,ambG,ambB[, dirIntensity[,dirR,dirG,dirB]]]])]]
    -- f.pepe:SetLight(true, false, -1, 0, 0, .7, .7, .7, .7, .6, 1, 1, 1)
    local omni = false
    local dirX = -1
    local dirY = 0
    local dirZ = 0
    local dirZ = 0.7
    local ambR = 0.7
    local ambG = 0.7
    local ambB = 0.7
    local dirR = 0.6
    local dirG = 1
    local dirB = 1
    f.pepe:SetLight(true, omni, dirX, dirY, dirZ, ambR, ambG, ambB, dirR, dirG, dirB)
    f.pepe.BG = f:CreateTexture(nil, "BACKGROUND")
    f.pepe.BG:SetPoint("CENTER", f.pepe, "CENTER", 0, 10)
    f.pepe.BG:SetHeight(80)
    f.pepe.BG:SetWidth(80)
    f.pepe.BG:SetTexture([[Interface\GLUES\Models\UI_NightborneElf\rg_shadow_elf]])
    f.pepe.BG:SetVertexColor(0, 0, 0, 1)
    f.pepe.BG:SetRotation(math.pi)
    f.pepe.BG:SetBlendMode("BLEND")

    --> RECENT CHANGES
    f.wpvp = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
    f.wpvp:SetFont(SM:Fetch("font", "Roboto Condensed BoldItalic"), 26, "OUTLINE")
    f.wpvp:SetPoint("TOPLEFT", f, "TOPLEFT", 14, -14)
    f.wpvp:SetHeight(26)
    f.wpvp:SetText("|cffffffffweiz|r|cffffa012PVP|r")

    f.recent = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
    f.recent:SetJustifyV("CENTER")
    f.recent:SetFont(SM:Fetch("font", "Roboto Condensed Bold"), 24, "NONE")
    f.recent:SetPoint("LEFT", f.wpvp, "RIGHT", 0, 0)
    f.recent:SetHeight(26)
    f.recent:SetText(": |cff42dcf4Recent Changes|r")

    --> CHANGELOG
    f.changes = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
    f.changes:SetPoint("LEFT", f, "LEFT", 22, 0)
    f.changes:SetPoint("TOP", f.wpvp, "BOTTOM", 0, -16)
    f.changes:SetFont(SM:Fetch("font", "PT Sans Narrow Bold"), 17, "NONE")
    f.changes:SetWidth(500)
    f.changes:SetShadowColor(0, 0, 0, 0.6)
    f.changes:SetShadowOffset(2, -2)
    f.changes:SetSpacing(1)

    f.changes:SetJustifyH("LEFT")
    f.changes:SetText(SplashDetailsText)

    f.changesbg = CreateFrame("Frame", "weizPVPSplashScreen", f)
    f.changesbg:SetFrameStrata("DIALOG")
    f.changesbg:SetFrameLevel(150)
    f.changesbg:SetPoint("TOP", f.changes, "TOP", 0, 2)
    f.changesbg:SetPoint("BOTTOM", f.changes, "BOTTOM", 0, -2)
    f.changesbg:SetPoint("LEFT", f, "LEFT", 8, 0)
    f.changesbg:SetPoint("RIGHT", f, "RIGHT", -8, 0)
    f.changesbg:SetBackdrop(
        {
            bgFile = SM:Fetch("background", "weizPVP: #FFFFFF"),
            tile = false,
            edgeFile = SM:Fetch("border", "weizPVP: Border"),
            edgeSize = 1,
            insets = {left = 1, right = 1, top = 1, bottom = 1}
        }
    )
    f.changesbg:SetBackdropColor(0.2, 0.2, 0.2, 1)
    f.changesbg:SetBackdropBorderColor(0, 0, 0, 1)
    f.changes:SetParent(f.changesbg)

    --> VERSION
    f.version = f:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
    f.version:SetPoint("BOTTOMRIGHT", f.changesbg, "TOPRIGHT", 0, 6)
    f.version:SetJustifyH("RIGHT")
    f.version:SetFont(SM:Fetch("font", "Accidental Presidency Italic"), 18, "NONE")
    f.version:SetText("|cffeeeeee" .. weizPVP.Addon.VERSION .. "|r  ")

    f.bg = f:CreateTexture(nil, "BACKGROUND")
    f.bg:SetPoint("TOPLEFT", f, "TOPLEFT")
    f.bg:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT")
    f.bg:SetDrawLayer("BACKGROUND", 0)
    f.bg:SetColorTexture(1, 1, 1, 1)
    f.bg:SetGradientAlpha("VERTICAL", 0.1, 0.1, 0.1, 0.9, 0.08, 0.08, 0.08, 1)

    --> OK BUTTON
    f.okayButton = CreateFrame("Button", "weizPVP: Splash OK Button", f)
    f.okayButton:SetSize(160, 32)
    f.okayButton:SetPoint("TOP", f.changesbg, "BOTTOM", 0, -8)
    f.okayButton:SetBackdrop(
        {
            bgFile = SM:Fetch("background", "weizPVP: #FFFFFF"),
            tile = false,
            edgeFile = SM:Fetch("border", "weizPVP: Border"),
            edgeSize = 1,
            insets = {left = 1, right = 1, top = 1, bottom = 1}
        }
    )
    f.okayButton:SetBackdropColor(0.4, 0.4, 0.4, 1)
    f.okayButton:SetBackdropBorderColor(0, 0, 0, 1)
    f.okayButton:SetScript(
        "OnClick",
        function()
            --> CLEAN ALL SETTINGS
            f:SetMovable(false)
            f:EnableMouse(false)
            f.okayButton:EnableMouse(false)
            --> Fade out
            UIFrameFadeOut(f, 0.3, 1, 0)
            weizPVP.Options.Addon.VersionSplashSeen = true
        end
    )

    --> OK TEXT
    f.okayButton.text = f.okayButton:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
    f.okayButton.text:SetPoint("CENTER")
    f.okayButton.text:SetJustifyH("CENTER")
    f.okayButton.text:SetTextColor(1, 1, 1, 1)
    f.okayButton.text:SetText("OK")
    f.okayButton.text:SetShadowOffset(1, -1)
    f.okayButton.text:SetFont(SM:Fetch("font", "Roboto Condensed Bold"), 20, "OUTLINE")
    f.okayButton:SetScript(
        "OnEnter",
        function()
            f.okayButton.text:SetShadowOffset(2, -2)
            f.okayButton:SetBackdropColor(0.7, 0.7, 0.7, 1)
        end
    )
    f.okayButton:SetScript(
        "OnLeave",
        function()
            f.okayButton.text:SetShadowOffset(1, -1)
            f.okayButton:SetBackdropColor(0.4, 0.4, 0.4, 1)
        end
    )

    f.okayButton:SetPoint("LEFT", f.changesbg, "LEFT", 0, 0)
    f.okayButton:SetPoint("RIGHT", f.changesbg, "RIGHT", 0, 0)

    f:SetHeight(48 + f.changes:GetHeight() + f.okayButton:GetHeight() + f.recent:GetHeight())
    f:ClearAllPoints()
    f:SetPoint("CENTER", WorldFrame, "CENTER", 0, 0)

    --=> Glow Border
    -----------------------------------------------------------
    local glowborder = 130
    f.windowglow = CreateFrame("CinematicModel", "splash glow", f)
    f.windowglow:SetFrameStrata("DIALOG")
    f.windowglow:SetFrameLevel(100)
    f.windowglow:SetModelDrawLayer("ARTWORK", 1)
    f.windowglow:SetParent(f)
    f.windowglow:SetPosition(-6, 0, -0.6)
    f.windowglow:SetPoint("CENTER", f, "CENTER")
    f.windowglow:SetPoint("TOPLEFT", f, "TOPLEFT", -1 * glowborder, glowborder)
    f.windowglow:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT", glowborder, -1 * glowborder + 60)
    f.windowglow:SetModel("world/generic/activedoodads/instanceportal/temporal_displacement.m2")
    f.windowglow:SetModelScale(1)
    f.windowglow:RefreshUnit()
    f.windowglow:ClearTransform()

    weizPVP.splash = f
    --> Set Frame position if using older options
    if weizPVP.Options.Addon.VersionSplashSeen == false then
        weizPVP.CoreFrame:ClearAllPoints()
        weizPVP.CoreFrame:SetPoint("TOPLEFT", weizPVP.splash, "TOPRIGHT", 6, -weizPVP.Options.Frames.Header.Height)
        weizPVP.HeaderFrame:ClearAllPoints()
        weizPVP.HeaderFrame:SetPoint("BOTTOM", weizPVP.CoreFrame, "TOP")
        weizPVP.HeaderFrame:SetPoint("LEFT", weizPVP.CoreFrame, "LEFT")
        weizPVP.HeaderFrame:SetPoint("RIGHT", weizPVP.CoreFrame, "RIGHT")
        weizPVP:SaveCoreFramePosition()
    end
    if not weizPVP.Options.Frames.Header.Point then
        weizPVP.CoreFrame:SetPoint(
            "TOPLEFT",
            UIParent,
            "BOTTOMLEFT",
            weizPVP.Options.Frames.X,
            weizPVP.Options.Frames.Y
        )
        weizPVP.HeaderFrame:ClearAllPoints()
        weizPVP.HeaderFrame:SetPoint("BOTTOMLEFT", weizPVP.CoreFrame, "TOPLEFT")
        weizPVP.HeaderFrame:SetPoint("BOTTOMRIGHT", weizPVP.CoreFrame, "TOPRIGHT")
        weizPVP.CoreFrame:SetWidth(weizPVP.Options.Frames.Width)
        weizPVP.CoreFrame:SetHeight(weizPVP.Options.Frames.Height)
        weizPVP:SaveCoreFramePosition()
    end
end

-------------------------------------------------------------------------------
--> Check Splash
-------------------------------------------------------------------------------
function weizPVP:CheckSplash()
    --> Reset if not seen splash screen before
    if not weizPVP.Options.Addon.VersionSplashSeen or weizPVP.Options.Addon.VersionSplashSeen == false then
        --> LOAD CHARACTER OPTIONS
        weizPVP.charDB:ResetDB()
        weizPVP.globalDB:ResetDB()
        weizPVP.charDB = LibStub("AceDB-3.0"):New("weizPVPOptions", weizPVP.defaults, true)
        weizPVP.Options = weizPVP.charDB.profile.Options
        --> LOAD GLOBAL PLAYER DB
        weizPVP.globalDB = LibStub("AceDB-3.0"):New("weizPVPDatabase", {}, false)
        weizPVP.PlayerDB = weizPVP.globalDB.global
    end

    --> Check to see if new version popup has been seen for this version
    local ShowSplash = not weizPVP.Options.Addon.VersionNumber or false
    ShowSplash = ShowSplash or weizPVP.Options.Addon.VersionNumber < weizPVP.Addon.SPLASH_SCREEN_FOR_VERSIONS_UNDER
    ShowSplash = ShowSplash or weizPVP.Options.DEBUG == true
    if ShowSplash then
        UIFrameFadeIn(weizPVP.splash, 0.2, 0, 1)
    else
        weizPVP.splash = nil
    end

    --> Update Versions
    weizPVP.Options.Addon.Version = weizPVP.Addon.VERSION
    weizPVP.Options.Addon.VersionNumber = weizPVP.Addon.VERSION_NUM
end
